==> hlw-core-0.0.2-20251205.085720-174-sources.jar: cn/gtmap/hlw/core/dto/zwfw/ZwfwItemValueDTO.java <==
package cn.gtmap.hlw.core.dto.zwfw;

import com.alibaba.fastjson.annotation.JSONField;
import lombok.Data;

import java.util.List;

/**
 * @author <a href="mailto:chenjia@gtmap.cn">chenjia</a>
 * @version 1.0, 2025/11/28
 * @description
 */
@Data
public class ZwfwItemValueDTO {
    private String applyTypeCode;
    private String applyTypeCodeTxt;
    private String applyCardTypeCode;
    private String applyCardTypeCodeTxt;
    private String applyName;
    private String applyCardNumber;
    @JSONField(name = "ywcj")
    private String sqlx;
    private String ywcjTxt;
    private List<ZwfwYwrDTO> sellinfogroup;
    private String sellsfdlrhfrbl;
    private String sellsfdlrhfrblTxt;
    private List<ZwfwYwrDlrDTO> selldlr;
    private List<ZwfwYwrFrDTO> sellfr;
    private String qhdm3;
    private String qhdm3Txt;
    private String qhdm2;
    private String qhdm2Txt;
    @JSONField(name = "qhdm")
    private String qydm;
    private String qhdmTxt;
    private String cqzh;
    @JSONField(name = "szc")
    private String fwszc;
    @JSONField(name = "zcs")
    private String fwzcs;
    private String fwlx;
    private String fwlxTxt;
    private String fwxz;
    private String fwjg;
    private String ghyt;
    private String jzmj;
    private String bdcdyh;
    private String jyjg;
    private String fkfs;
    private String fkfsTxt;
    private String zl;
    private List<ZwfwQlrQueryDTO> buyinfogroup;
    private String sffbcz;
    private String sffbczTxt;
    private String buysfdlrhfrbl;
    private String buysfdlrhfrblTxt;
    private List<ZwfwQlrDlrDTO> buydlr;
    private List<ZwfwQlrFrDTO> buyfr;
    private String selldyyhmc;
    private String selldyzjzl;
    private String selldyzjzlTxt;
    private String selldyzjhm;
    private String selldylxdh;
    private String selldygyfs;
    private String selldygyfsTxt;
    private String selldyqlrlx;
    private String selldyqlrlxTxt;
    private String selldydjzmh;
    private String selldyfs;
    private String selldyfsTxt;
    private String sellbdbzqe;
    private String sellzgzqe;
    private String selldyqssj;
    private String selldyjssj;
    private String selldysfdlrhfrbl;
    private String selldysfdlrhfrblTxt;
    private String selldydlrzjzl;
    private String selldydlrzjzlTxt;
    private String selldydlrzjhm;
    private String selldydlrlxdh;
    private String selldydlrxm;
    private String selldyfddbrzjzl;
    private String selldyfddbrzjzlTxt;
    private String selldyfddbrlxdh;
    private String selldyfddbrzjhm;
    private String selldyfddbrxm;
    private String qlrmc;
    @JSONField(name = "qlrzjzl")
    private String qlrsfzjzl;
    private String qlrzjzlTxt;
    @JSONField(name = "qlrzjbh")
    private String qlrzjh;
    private String qlrlxdh;
    @JSONField(name = "dygyfs")
    private String gyfs;
    private String dygyfsTxt;
    @JSONField(name = "qlrlx")
    private String gxrzldm;
    private String qlrlxTxt;
    private String dyfs;
    private String dyfsTxt;
    private String bdbzqe;
    private String zgzqe;
    private String zwlxkssj;
    private String zwlxjssj;
    private String sfczdyzyxz;
    private String sfczdyzyxzTxt;
    private String qlrsfdlrhfrbl;
    private String qlrsfdlrhfrblTxt;
    @JSONField(name = "qlrdlrxm")
    private String dlrmc;
    @JSONField(name = "qlrdlrzjzl")
    private String dlrsfzjzl;
    private String qlrdlrzjzlTxt;
    @JSONField(name = "qlrdlrzjbh")
    private String dlrzjh;
    @JSONField(name = "qlrdlrdh")
    private String dlrdh;
    private String qlrfrxm;
    private String qlrfrzjzl;
    private String qlrfrzjzlTxt;
    private String qlrfrzjbh;
    private String qlrfrdh;
    private String shh;
    private String dhh;
    private String qhh;
    private String receiveWayCode;
    private String receiveWayCodeTxt;
    @JSONField(name = "mobile")
    private String lzrlxdh;
    @JSONField(name = "receiveMan")
    private String lzrmc;
    @JSONField(name = "address")
    private String lzxxdz;
    private String telphone;
    @JSONField(name = "contactManCardtypeCode")
    private String sjryb;
    private String projPwd;
    private String thirdOrderNo;
}

==> hlw-core-0.0.2-20251208.032658-175-sources.jar: cn/gtmap/hlw/core/dto/zwfw/ZwfwItemValueDTO.java <==
package cn.gtmap.hlw.core.dto.zwfw;

import cn.gtmap.hlw.core.annotation.ZdDzConfig;
import cn.gtmap.hlw.core.constant.dict.ZdDzConstant;
import com.alibaba.fastjson.annotation.JSONField;
import lombok.Data;

import java.util.List;

/**
 * @author <a href="mailto:chenjia@gtmap.cn">chenjia</a>
 * @version 1.0, 2025/11/28
 * @description
 */
@Data
public class ZwfwItemValueDTO {
    private String applyTypeCode;
    private String applyTypeCodeTxt;
    private String applyCardTypeCode;
    private String applyCardTypeCodeTxt;
    private String applyName;
    private String applyCardNumber;
    @ZdDzConfig(field = "sqlx", tableName = ZdDzConstant.ZD_DZ_SQLX, mcToDM = true)
    @JSONField(name = "ywcj")
    private String sqlx;
    private String ywcjTxt;
    private List<ZwfwYwrDTO> sellinfogroup;
    private String sellsfdlrhfrbl;
    private String sellsfdlrhfrblTxt;
    private List<ZwfwYwrDlrDTO> selldlr;
    private List<ZwfwYwrFrDTO> sellfr;
    private String qhdm3;
    private String qhdm3Txt;
    private String qhdm2;
    private String qhdm2Txt;
    @JSONField(name = "qhdm")
    private String qydm;
    private String qhdmTxt;
    private String cqzh;
    @JSONField(name = "szc")
    private String fwszc;
    @JSONField(name = "zcs")
    private String fwzcs;
    private String fwlx;
    private String fwlxTxt;
    private String fwxz;
    private String fwjg;
    private String ghyt;
    private String jzmj;
    private String bdcdyh;
    private String jyjg;
    private String fkfs;
    private String fkfsTxt;
    private String zl;
    private List<ZwfwQlrQueryDTO> buyinfogroup;
    private String sffbcz;
    private String sffbczTxt;
    private String buysfdlrhfrbl;
    private String buysfdlrhfrblTxt;
    private List<ZwfwQlrDlrDTO> buydlr;
    private List<ZwfwQlrFrDTO> buyfr;
    private String selldyyhmc;
    private String selldyzjzl;
    private String selldyzjzlTxt;
    private String selldyzjhm;
    private String selldylxdh;
    private String selldygyfs;
    private String selldygyfsTxt;
    private String selldyqlrlx;
    private String selldyqlrlxTxt;
    private String selldydjzmh;
    private String selldyfs;
    private String selldyfsTxt;
    private String sellbdbzqe;
    private String sellzgzqe;
    private String selldyqssj;
    private String selldyjssj;
    private String selldysfdlrhfrbl;
    private String selldysfdlrhfrblTxt;
    private String selldydlrzjzl;
    private String selldydlrzjzlTxt;
    private String selldydlrzjhm;
    private String selldydlrlxdh;
    private String selldydlrxm;
    private String selldyfddbrzjzl;
    private String selldyfddbrzjzlTxt;
    private String selldyfddbrlxdh;
    private String selldyfddbrzjhm;
    private String selldyfddbrxm;
    private String qlrmc;
    @JSONField(name = "qlrzjzl")
    private String qlrsfzjzl;
    private String qlrzjzlTxt;
    @JSONField(name = "qlrzjbh")
    private String qlrzjh;
    private String qlrlxdh;
    @JSONField(name = "dygyfs")
    private String gyfs;
    private String dygyfsTxt;
    @JSONField(name = "qlrlx")
    private String gxrzldm;
    private String qlrlxTxt;
    private String dyfs;
    private String dyfsTxt;
    private String bdbzqe;
    private String zgzqe;
    private String zwlxkssj;
    private String zwlxjssj;
    private String sfczdyzyxz;
    private String sfczdyzyxzTxt;
    private String qlrsfdlrhfrbl;
    private String qlrsfdlrhfrblTxt;
    @JSONField(name = "qlrdlrxm")
    private String dlrmc;
    @JSONField(name = "qlrdlrzjzl")
    private String dlrsfzjzl;
    private String qlrdlrzjzlTxt;
    @JSONField(name = "qlrdlrzjbh")
    private String dlrzjh;
    @JSONField(name = "qlrdlrdh")
    private String dlrdh;
    private String qlrfrxm;
    private String qlrfrzjzl;
    private String qlrfrzjzlTxt;
    private String qlrfrzjbh;
    private String qlrfrdh;
    private String shh;
    private String dhh;
    private String qhh;
    private String receiveWayCode;
    private String receiveWayCodeTxt;
    @JSONField(name = "mobile")
    private String lzrlxdh;
    @JSONField(name = "receiveMan")
    private String lzrmc;
    @JSONField(name = "address")
    private String lzxxdz;
    private String telphone;
    @JSONField(name = "contactManCardtypeCode")
    private String sjryb;
    private String projPwd;
    private String thirdOrderNo;
}
